#include <u.h>
#include <libc.h>
#include <bio.h>
#include <ip.h>

void
usage(void)
{
	fprint(2, "usage: %s [-n]\n", argv0);
	fprint(2, "   collate IP addresses from field <n> into a cidr reprisentation\n");
	exits("usage");
}

void
main(int argc, char *argv[])
{
	int i, fld;
	Biobuf in;
	uint common, net, lo, hi, ip;
	char *args[10], *line;
	uchar tmp[IPaddrlen];

	fld = 1;
	ARGBEGIN{
	case '1': case '2': case '3': case '4': 
	case '5': case '6': case '7': case '8': case '9':
		fld = atoi(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND;

	if(fld <= 0 || fld >= nelem(args))
		sysfatal("bad field, <=0 or >=%d\n", nelem(args));

	lo = 0xffffffff;
	hi = 0;

	fmtinstall('V', eipfmt);

	Binit(&in, OREAD, 0);
	while((line = Brdline(&in, '\n')) != nil){
		line[Blinelen(&in)-1] = 0;

		if(tokenize(line, args, nelem(args)) < fld)
			continue;

		ip = parseip(tmp, args[fld-1]);
		if(ip < lo)
			lo = ip;
		if(ip > hi)
			hi = ip;
	}
	Bterm(&in);

	common = ~(lo ^ hi);
	for(i = 31; i >= 0; i--){
		if((common & (1 << i)) == 0){
			net = ~((1<<i)-1) & lo;
			print("%d.%d.%d.%d/%d\n", (net>>24)&0xff, (net>>16)&0xff, (net>>8)&0xff, net&0xff, 31-i);
			break;
		}
	}

	exits(nil);
}
